# This file is generated by SciPy's build process
# It contains system_info results at the time of building this package.
from enum import Enum

__all__ = ["show"]
_built_with_meson = True


class DisplayModes(Enum):
    stdout = "stdout"
    dicts = "dicts"


def _cleanup(d):
    """
    Removes empty values in a `dict` recursively
    This ensures we remove values that Meson could not provide to CONFIG
    """
    if isinstance(d, dict):
        return { k: _cleanup(v) for k, v in d.items() if v != '' and _cleanup(v) != '' }
    else:
        return d


CONFIG = _cleanup(
    {
        "Compilers": {
            "c": {
                "name": "gcc",
                "linker": r"ld.aix",
                "version": "10.3.0",
                "commands": r"/opt/freeware/bin/gcc, -pthread, -fno-extern-tls-init",
                "args": r"-maix64",
                "linker args": r"-maix64, -Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib, -L/opt/freeware/lib/pthread/, -maix64",
            },
            "cython": {
                "name": r"cython",
                "linker": r"cython",
                "version": r"3.0.8",
                "commands": r"cython",
                "args": r"",
                "linker args": r"",
            },
            "c++": {
                "name": "gcc",
                "linker": r"ld.aix",
                "version": "10.3.0",
                "commands": r"/opt/freeware/bin/g++, -pthread, -fno-extern-tls-init",
                "args": r"-maix64",
                "linker args": r"-maix64, -Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib, -L/opt/freeware/lib/pthread/, -maix64",
            },
            "fortran": {
                "name": "gcc",
                "linker": r"ld.aix",
                "version": "10.3.0",
                "commands": r"gfortran",
                "args": r"-pthread, -maix64",
                "linker args": r"-maix64, -Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib, -L/opt/freeware/lib/pthread/, -pthread, -maix64",
            },
            "pythran": {
                "version": r"0.17.0",
                "include directory": r"../../../../../../opt/freeware/lib/python3.9/site-packages/pythran"
            },
        },
        "Machine Information": {
            "host": {
                "cpu": r"powerpc",
                "family": r"ppc",
                "endian": r"big",
                "system": r"aix",
            },
            "build": {
                "cpu": r"powerpc",
                "family": r"ppc",
                "endian": r"big",
                "system": r"aix",
            },
            "cross-compiled": bool("False".lower().replace('false', '')),
        },
        "Build Dependencies": {
            "blas": {
                "name": "openblas",
                "found": bool("True".lower().replace('false', '')),
                "version": "0.3.28",
                "detection method": "pkgconfig",
                "include directory": r"/opt/freeware/include/openblas",
                "lib directory": r"/opt/freeware/lib",
                "openblas configuration": r"USE_64BITINT= DYNAMIC_ARCH=1 DYNAMIC_OLDER= NO_CBLAS= NO_LAPACK= NO_LAPACKE= NO_AFFINITY=1 USE_OPENMP=1 POWER7 MAX_THREADS=32",
                "pc file directory": r"/opt/freeware/lib/pkgconfig",
            },
            "lapack": {
                "name": "openblas",
                "found": bool("True".lower().replace('false', '')),
                "version": "0.3.28",
                "detection method": "pkgconfig",
                "include directory": r"/opt/freeware/include/openblas",
                "lib directory": r"/opt/freeware/lib",
                "openblas configuration": r"USE_64BITINT= DYNAMIC_ARCH=1 DYNAMIC_OLDER= NO_CBLAS= NO_LAPACK= NO_LAPACKE= NO_AFFINITY=1 USE_OPENMP=1 POWER7 MAX_THREADS=32",
                "pc file directory": r"/opt/freeware/lib/pkgconfig",
            },
            "pybind11": {
                "name": "pybind11",
                "version": "2.13.1",
                "detection method": "config-tool",
                "include directory": r"unknown",
            },
        },
        "Python Information": {
            "path": r"/opt/freeware/bin/python3.9",
            "version": "3.9",
        },
    }
)


def _check_pyyaml():
    import yaml

    return yaml


def show(mode=DisplayModes.stdout.value):
    """
    Show libraries and system information on which SciPy was built
    and is being used

    Parameters
    ----------
    mode : {`'stdout'`, `'dicts'`}, optional.
        Indicates how to display the config information.
        `'stdout'` prints to console, `'dicts'` returns a dictionary
        of the configuration.

    Returns
    -------
    out : {`dict`, `None`}
        If mode is `'dicts'`, a dict is returned, else None

    Notes
    -----
    1. The `'stdout'` mode will give more readable
       output if ``pyyaml`` is installed

    """
    if mode == DisplayModes.stdout.value:
        try:  # Non-standard library, check import
            yaml = _check_pyyaml()

            print(yaml.dump(CONFIG))
        except ModuleNotFoundError:
            import warnings
            import json

            warnings.warn("Install `pyyaml` for better output", stacklevel=1)
            print(json.dumps(CONFIG, indent=2))
    elif mode == DisplayModes.dicts.value:
        return CONFIG
    else:
        raise AttributeError(
            f"Invalid `mode`, use one of: {', '.join([e.value for e in DisplayModes])}"
        )
